program calmain

  use globals
  use caltau
  use calp
  use calpf
  use calrt
  implicit none

  integer :: i, j, k, l, m, n, o
!  integer :: i1
  integer :: num
  integer, parameter :: timestep = 10001
  integer, parameter :: lamax = 96
  real(8) :: lam                     ! 吸収線の波長
  real(8) :: it                      ! 大気上端からの短波の放射輝度
  real(8) :: tt                      ! 大気上端の輝度温度
  real(8) :: p1, pl                  ! 層間の圧力
  real(8) :: delta                   ! 
  real(8), dimension(lay) :: k1      ! 吸収係数
  real(8), dimension(lay) :: rho     ! 大気の密度
  real(8), dimension(lay) :: g1      ! 関数g1
  real(8), dimension(lay-1) :: dtau  ! 光学的深さの間隔
  real(8), dimension(lay) :: tau     ! 層間の光学的深さ
  real(8), dimension(lay-1) :: tauc  ! 気層の光学的深さ
  real(8), dimension(lay-1) :: pc    ! 気層の圧力
  real(8), dimension(lay) :: t       ! 層間の温度
  real(8), dimension(lay-1) :: dtc   ! 気層の温度の時間変化率
  real(8), dimension(lay-1) :: tc    ! 気層の温度
  real(8), dimension(lay) :: b       ! プランク関数
  real(8), dimension(lay-1) :: bc       ! プランク関数
  real(8), dimension(lay) :: in      ! 単色波の正味の放射輝度
  real(8), dimension(lay) :: intot   ! 正味の放射輝度の波長合計
  real(8), dimension(lay-1) :: fc    ! 正味の放射フラックスの差

  ! global variables
  g = 9.8                            ! 9.8 m/s^2
  height = 5.0 * 10.0 ** 4.0         ! 50 km
  sheight = 8.0 * 10.0 ** 3.0        ! 8.0 km
  sheightab = 2.0 * 10.0 ** 3.0      ! 2.0 km
  theta = 0.0
  mu = cos(theta)
  pi = 2.0d0 * acos(0.0d0)
  sigma = 5.67 * 10 ** (- 8.0)       ! 5.67 * 10^(-8) Wm^(-2)K^(-4)
  h = 6.63 * 10.0 ** (-34.0)         ! 6.63 * 10^(-34) Js
  c = 3.0 * 10 ** 8.0                ! 3.0 * 10^8 m/s
  kap = 1.38 * 10.0 ** (-23.0)       ! 1.38 *10^(-23) J/K
  dz = (1.0 / (lay - 1.0)) * height  ! 1.0 km
  rhoabs = 1.0 * 10.0 ** (-2.0)      ! 1.0 * 10^(-2) kg/m^3
  cp = 1.0 * 10.0 ** 3.0             ! 1000 J/kgK               
  rhos = 1.3                         ! 1.3 kg/m^3
  dl = 1.0 * 10.0 ** (-8.0)          ! 10^(-6)
  dt = (3.6 * 10.0 ** (3.0)) * 8.0   ! 8 h

  ! 定数
  tt = 255.0
  delta = 10.0 ** (-2.0)

  ! 初期値・分布
!    k1(:) = 0.00125
!    k1(:) = 0.0125
    k1(:) = 0.0375

!    k1(:) = 0.0049
!    k1(:) = 0.049
!    k1(:) = 0.147

    ! 吸収係数は一定値に固定

  call caltau1(k1, rho, dtau, tau, tauc, g1)
  call calp1(p1, pl, pc)

  ! tc, t の初期分布
  t(:) = 1.6 * 10.0 ** 2.0   ! 160 K / 360 K
  tc(:) = 1.6 * 10.0 ** 2.0  ! 160 K / 360 K

  do i = 1, timestep
  
  intot(:) = 0.0
 
  ! 波長のループ
    do j = 1, lamax
      lam = (4.0 * 10.0 ** (- 6.0)) + (real(j-1) * dl)
      call calpf1(lam, tt, it)
      call calpf2(lam, t, b)
      call calpf3(lam, tc, bc)
      call calrt1(it, b, g1, dtau, in)
      do k = 1, lay
        intot(k) = intot(k) + (in(k) * dl)
!        intot(k) = intot(k) + in(k)
      end do
    end do

    ! 正味のフラックスのループ
    do l = 1, lay-1 
      fc(l) = pi * (intot(l) - intot(l+1))  
    end do

    ! 温度のループ
    do m = 1, lay-1
      dtc(m) = - (1.0 / (cp * ((rho(m) + rho(m+1)) / 2.0))) * (fc(m) / dz)
      tc(m) = tc(m) + (dtc(m) * dt)
!    write(*,*) dtc(m), dt, dl, cp
    end do
   
    do n = 2, lay-1
      t(n) = (tc(n-1) + tc(n)) / 2.0
    end do
    t(1) = (tc(1) - (t(2) - tc(1)))
    t(lay) = (tc(lay-1) - (t(lay-1) - tc(lay-1)))  

    if (intot(lay-1) - intot(1) < delta .and. &
        intot(1) - intot(lay-1) < delta       &
       ) then
!    if (dtc(1) < delta .and. &
!        dtc(lay-1)< delta    &
!       ) then
    write(*, *) intot(1), intot(lay-1)
      num = i
      open(unit=num, status='unknown')
        write(num, *) 50000, tau(1), p1, t(1)
      close(unit=num, status='keep')
      open(unit=num, status='unknown', access='append')
        do o = 1, lay-1 
          write(num,*) (lay - o) * 1000 - 500, tauc(o), pc(o), tc(o)
        end do 
      close(unit=num, status='keep')
      open(unit=num, status='unknown', access='append')
        write(num, *) 0, tau(lay), pl, t(lay) 
      close(unit=num, status='keep')
      exit
    end if

    if (mod(i-1,30) == 0 ) then
      num = i
      open(unit=num, status='unknown')
        write(num, *) 50000, tau(1), p1, t(1)
      close(unit=num, status='keep')
      open(unit=num, status='unknown', access='append')
        do o = 1, lay-1 
          write(num,*) (lay - o) * 1000 - 500, tauc(o), pc(o), tc(o)
        end do 
      close(unit=num, status='keep')
      open(unit=num, status='unknown', access='append')
        write(num, *) 0, tau(lay), pl, t(lay) 
      close(unit=num, status='keep')

    end if

  end do

end
