module calp

  use globals
  implicit none
  contains

subroutine calp1( &
  & p1,           & !(out)
  & pl,           & !(out)
  & pc            & !(out)
  & )

  integer :: i, j, k, l
!  integer :: i1
  real(8), intent(out) :: p1, pl                ! 層間の圧力
  real(8), dimension(lay) :: rho                ! 大気の密度
  real(8), dimension(lay-1) :: dp               ! 圧力の間隔
  real(8), dimension(lay) :: p                  ! 層間の圧力
  real(8), dimension(lay-1), intent(out) :: pc  ! 気層の圧力

  ! global variables
  g = 9.8                            ! 9.8 m/s^2
  height = 5.0 * 10.0 ** 4.0         ! 50 km
  sheight = 8.0 * 10.0 ** 3.0        ! 8.0 km
  sheightab = 2.0 * 10.0 ** 3.0      ! 2.0 km
  theta = 0.0
  mu = cos(theta)
  pi = 2.0d0 * acos(0.0d0)
  sigma = 5.67 * 10 ** (- 8.0)       ! 5.67 * 10^(-8) Wm^(-2)K^(-4)
  h = 6.63 * 10.0 ** (-34.0)         ! 6.63 * 10^(-34) Js
  c = 3.0 * 10 ** 8.0                ! 3.0 * 10^8 m/s
  kap = 1.38 * 10.0 ** (-23.0)       ! 1.38 *10^(-23) J/K
  dz = (1.0 / (lay - 1.0)) * height  ! 1.0 km
  rhoabs = 1.0 * 10.0 ** (-2.0)      ! 1.0 * 10^(-2) kg/m^3
  cp = 1.0 * 10.0 ** 3.0             ! 1000 J/kgK               
  rhos = 1.3                         ! 1.3 kg/m^3
  dl = 1.0 * 10.0 ** (-8.0)          ! 10^(-8)
  dt = (3.6 * 10.0 ** (3.0)) * 8.0   ! 8 h

  ! 初期値・分布
  do i = lay, 1, -1  
    rho(i) = rhos * exp(- (real(lay) - real(i)) * 1000 / sheight)  
  end do
  
  ! dp, p, pc の決定
  do j = 1, lay-1
    dp(j) = ((rho(j) + rho(j+1)) / 2.0) * g * dz / 100
  end do 

  p(lay) = 1.0 * 10.0 ** 3.0
  do k = lay-1, 1, -1
    p(k) = p(k+1) - dp(k)
  end do 
  p1 = p(1)
  pl = p(lay)

  do l = 1, lay-1
    pc(l) = (p(l) + p(l+1)) /2.0
  end do 

  ! 確認用出力
!  open(unit=13, file='resp.dat', status='unknown')
!  do i1 = 1, lay 
!    write(13, *) i1, p(i1), pc(i1)
!  end do
!  close(unit=13, status='keep')

end subroutine calp1

end module calp

