module calpf

  use globals
  implicit none
  contains

subroutine calpf1( &
  & lam,           & !(in)
  & tx,            & !(in)
  & bx             & !(out)
  & )

  integer :: i
!  integer :: i1
  real(8), intent(in) :: lam  ! 吸収線の波長
  real(8), intent(in) :: tx   ! 気層の温度
  real(8), intent(out) :: bx  ! プランク関数

  ! global variables
  g = 9.8                            ! 9.8 m/s^2
  height = 5.0 * 10.0 ** 4.0         ! 50 km
  sheight = 8.0 * 10.0 ** 3.0        ! 8.0 km
  sheightab = 2.0 * 10.0 ** 3.0      ! 2.0 km
  theta = 0.0
  mu = cos(theta)
  pi = 2.0d0 * acos(0.0d0)
  sigma = 5.67 * 10 ** (- 8.0)       ! 5.67 * 10^(-8) Wm^(-2)K^(-4)
  h = 6.63 * 10.0 ** (-34.0)         ! 6.63 * 10^(-34) Js
  c = 3.0 * 10 ** 8.0                ! 3.0 * 10^8 m/s
  kap = 1.38 * 10.0 ** (-23.0)       ! 1.38 *10^(-23) J/K
  dz = (1.0 / (lay - 1.0)) * height  ! 1.0 km
  rhoabs = 1.0 * 10.0 ** (-2.0)      ! 1.0 * 10^(-2) kg/m^3
  cp = 1.0 * 10.0 ** 3.0             ! 1000 J/kgK               
  rhos = 1.3                         ! 1.3 kg/m^3
  dl = 1.0 * 10.0 ** (-6.0)          ! 10^(-6)
  dt = (3.6 * 10.0 ** (3.0)) * 8.0   ! 8 h

  ! プランク関数の計算
  do i = 1, lay
    bx = ((2.0 * h * (c ** 2.0)) / (lam ** 5.0)) &
       * (1.0 / (exp((h * c) / (kap * lam * tx)) - 1.0))
  end do

end subroutine calpf1

subroutine calpf2( &
  & lam,           & !(in)
  & t,             & !(in)
  & b              & !(out)
  & )

  integer :: i
!  integer :: i1
  real(8), intent(in) :: lam                 ! 吸収線の波長
  real(8), dimension(lay), intent(in) :: t   ! 気層の温度
  real(8), dimension(lay), intent(out) :: b  ! プランク関数


  ! global variables
  g = 9.8                            ! 9.8 m/s^2
  height = 5.0 * 10.0 ** 4.0         ! 50 km
  sheight = 8.0 * 10.0 ** 3.0        ! 8.0 km
  sheightab = 2.0 * 10.0 ** 3.0      ! 2.0 km
  theta = 0.0
  mu = cos(theta)
  pi = 2.0d0 * acos(0.0d0)
  sigma = 5.67 * 10 ** (- 8.0)       ! 5.67 * 10^(-8) Wm^(-2)K^(-4)
  h = 6.63 * 10.0 ** (-34.0)         ! 6.63 * 10^(-34) Js
  c = 3.0 * 10 ** 8.0                ! 3.0 * 10^8 m/s
  kap = 1.38 * 10.0 ** (-23.0)       ! 1.38 *10^(-23) J/K
  dz = (1.0 / (lay - 1.0)) * height  ! 1.0 km
  rhoabs = 2.0 * 10.0 ** (-2.0)      ! 2.0 * 10^(-3) kg/m^3
  cp = 1.617 * 10.0 ** 3.0           ! 1617J/kgK               
  rhos = 1.3                         ! 1.3 kg/m^3
  dl = 1.0 * 10.0 ** (-6.0)          ! 10^(-6)
  dt = (3.6 * 10.0 ** (2.0)) * 8.0   ! 8 h

  ! プランク関数の計算
  do i = 1, lay
    b(i) = ((2.0 * h * (c ** 2.0)) / (lam ** 5.0)) &
         * (1.0 / (exp((h * c) / (kap * lam * t(i))) - 1.0))
  
  end do

end subroutine calpf2

subroutine calpf3( &
  & lam,           & !(in)
  & t,             & !(in)
  & b              & !(out)
  & )

  integer :: i
!  integer :: i1
  real(8), intent(in) :: lam                 ! 吸収線の波長
  real(8), dimension(lay-1), intent(in) :: t   ! 気層の温度
  real(8), dimension(lay-1), intent(out) :: b  ! プランク関数

  ! global variables
  g = 9.8                            ! 9.8 m/s^2
  height = 5.0 * 10.0 ** 4.0         ! 86 km
  sheight = 5.0 * 10.0 ** 3.0        ! 8.6 km
  theta = 0.0
  mu = cos(theta)
  pi = 2.0d0 * acos(0.0d0)
  sigma = 5.67 * 10 ** (- 8.0)       ! 5.67 * 10^(-8) Wm^(-2)K^(-4)
  h = 6.63 * 10.0 ** (-34.0)         ! 6.63 * 10^(-34) Js
  c = 3.0 * 10 ** 8.0                ! 3.0 * 10^8 m/s
  kap = 1.38 * 10.0 ** (-23.0)       ! 1.38 *10^(-23) J/K
  dz = (1.0 / (lay - 1.0)) * height  ! 1.0 km
  rhoabs = 2.0 * 10.0 ** (-2.0)      ! 2.0 * 10^(-3) kg/m^3
  cp = 1.617 * 10.0 ** 3.0           ! 1617J/kgK               
  rhos = 1.3                         ! 1.3 kg/m^3
  dl = 1.0 * 10.0 ** (-6.0)          ! 10^(-6)
  dt = (3.6 * 10.0 ** (2.0)) * 8.0   ! 8 h

  ! プランク関数の計算
  do i = 1, lay-1
    b(i) = ((2.0 * h * (c ** 2.0)) / (lam ** 5.0)) &
         * (1.0 / (exp((h * c) / (kap * lam * t(i))) - 1.0))
  end do

end subroutine calpf3

end module calpf
