module calrt

  use globals
  implicit none
  contains

subroutine calrt1( &
  & it,            & !(in)
  & b,             & !(in)
  & g1,            & !(in)
  & dtau,          & !(in)
  & in             & !(out)
  & )

  integer :: i, j, k, l, m
!  integer :: i1
  real(8) :: ig                                  ! 地面からの放射輝度
  real(8), intent(in) :: it                      ! 大気上端からの放射輝度
  real(8), dimension(lay), intent(in) :: g1      ! 関数g1
  real(8), dimension(lay) :: g2                  ! 関数g2
  real(8), dimension(lay) :: g3                  ! 関数g3
  real(8), dimension(lay), intent(in) :: b       ! プランク関数
  real(8), dimension(lay-1), intent(in) :: dtau  ! 光学的深さの間隔
  real(8), dimension(lay) :: iu, id              ! 上向き,下向きの放射輝度
  real(8), dimension(lay), intent(out) :: in     ! 正味の放射輝度

  ! global variables
  g = 9.8                            ! 9.8 m/s^2
  height = 5.0 * 10.0 ** 4.0         ! 50 km
  sheight = 8.0 * 10.0 ** 3.0        ! 8.0 km
  sheightab = 2.0 * 10.0 ** 3.0      ! 2.0 km
  theta = 0.0
  mu = cos(theta)
  pi = 2.0d0 * acos(0.0d0)
  sigma = 5.67 * 10 ** (- 8.0)       ! 5.67 * 10^(-8) Wm^(-2)K^(-4)
  h = 6.63 * 10.0 ** (-34.0)         ! 6.63 * 10^(-34) Js
  c = 3.0 * 10 ** 8.0                ! 3.0 * 10^8 m/s
  kap = 1.38 * 10.0 ** (-23.0)       ! 1.38 *10^(-23) J/K
  dz = (1.0 / (lay - 1.0)) * height  ! 1.0 km
  rhoabs = 1.0 * 10.0 ** (-2.0)      ! 1.0 * 10^(-2) kg/m^3
  cp = 1.0 * 10.0 ** 3.0             ! 1000 J/kgK               
  rhos = 1.3                         ! 1.3 kg/m^3
  dl = 1.0 * 10.0 ** (-6.0)          ! 10^(-6)
  dt = (3.6 * 10.0 ** (3.0)) * 8.0   ! 8 h

 ! 放射伝達方程式(下向き)
  g3(1) = 0.0
!  g4(1) = 0.0 
  do k = 2, lay 
    g3(k) = g3(k-1) + (dtau(k-1) * ((b(k-1) / g1(k-1)) + (b(k) / g1(k))) / 2.0)
!    g4(k) = g4(k-1) + (dtau(k-1) * ((2.0 / g1(k-1)) + (1.0 / g1c(k-1)) + (2.0 / g1(k))) / 5.0)
  end do

  do l = 1, lay
    id(l) = (g1(l) / mu) * g3(l)
  end do

  ! 放射伝達方程式(上向き)
   g2(lay) = 0.0
!   g5(lay) = 0.0
   ig = it + id(lay)
   do i = lay-1, 1, -1
     g2(i) = g2(i+1) + (dtau(i) * ((b(i+1) * g1(i+1)) + (b(i) * g1(i))) / 2.0) 
!     g5(i) = g5(i+1) + (dtau(i) * ((1.0 * g1(i+1)) + (1.0 * g1(i))) / 2.0) 
   end do

   do j = 1, lay
     iu(j) = (ig * (g1(lay) / g1(j))) + ((1.0 / (g1(j) * mu)) * g2(j))
   end do 

  ! 正味の放射輝度
  do m = 1, lay
    in(m) = iu(m) - id(m)
  end do


  ! 確認用出力 
!  open(unit=12, file='res2.dat', status='unknown')
!    do i1 = 1, lay 
!      write(*,*) g4(lay), g5(1)
!    end do
!      write(*,*) it, iu(1), ig, id(lay)
!    close(unit=11, status='keep')

end subroutine calrt1

end module calrt
